@@ -40,25 +40,30 @@ def get_transform_primitives():
 
 
 def list_primitives():
-    trans_names, trans_primitives = _get_names_primitives(get_transform_primitives)
+    trans_names, trans_primitives, valid_inputs, return_type = _get_names_primitives(get_transform_primitives)
     trans_dask = [Library.DASK in primitive.compatibility for primitive in trans_primitives]
     trans_koalas = [Library.KOALAS in primitive.compatibility for primitive in trans_primitives]
     transform_df = pd.DataFrame({'name': trans_names,
                                  'description': _get_descriptions(trans_primitives),
                                  'dask_compatible': trans_dask,
-                                 'koalas_compatible': trans_koalas})
+                                 'koalas_compatible': trans_koalas,
+                                 'valid_inputs': valid_inputs,
+                                 'return_type': return_type})
     transform_df['type'] = 'transform'
 
-    agg_names, agg_primitives = _get_names_primitives(get_aggregation_primitives)
+    agg_names, agg_primitives, valid_inputs, return_type = _get_names_primitives(get_aggregation_primitives)
     agg_dask = [Library.DASK in primitive.compatibility for primitive in agg_primitives]
     agg_koalas = [Library.KOALAS in primitive.compatibility for primitive in agg_primitives]
     agg_df = pd.DataFrame({'name': agg_names,
                            'description': _get_descriptions(agg_primitives),
                            'dask_compatible': agg_dask,
-                           'koalas_compatible': agg_koalas})
+                           'koalas_compatible': agg_koalas,
+                           'valid_inputs': valid_inputs,
+                           'return_type': return_type})
     agg_df['type'] = 'aggregation'
 
-    return pd.concat([agg_df, transform_df], ignore_index=True)[['name', 'type', 'dask_compatible', 'koalas_compatible', 'description']]
+    columns = ['name', 'type', 'dask_compatible', 'koalas_compatible', 'description', 'valid_inputs', 'return_type']
+    return pd.concat([agg_df, transform_df], ignore_index=True)[columns]
 
 
 def get_default_aggregation_primitives():
@@ -101,10 +106,25 @@ def _get_descriptions(primitives):
 def _get_names_primitives(primitive_func):
     names = []
     primitives = []
+    valid_inputs = []
+    return_type = []
     for name, primitive in primitive_func().items():
         names.append(name)
         primitives.append(primitive)
-    return names, primitives
+        input_types = _get_names_valid_inputs(primitive.input_types)
+        valid_inputs.append(', '.join(input_types))
+        return_type.append(getattr(primitive.return_type, '__name__', None))
+    return names, primitives, valid_inputs, return_type
+
+
+def _get_names_valid_inputs(input_types):
+    names = set()
+    for input_type in input_types:
+        if isinstance(input_type, list):
+            names |= _get_names_valid_inputs(input_type)
+        else:
+            names.add(input_type.__name__)
+    return names
 
 
 def list_primitive_files(directory):
