@@ -59,11 +59,10 @@ from featuretools.primitives.utils import (
 )
 from featuretools.synthesis.deep_feature_synthesis import match
 from featuretools.tests.testing_utils import feature_with_name, to_pandas
-from featuretools.utils.gen_utils import Library, import_or_none
+from featuretools.utils.gen_utils import Library
+from featuretools.utils.koalas_utils import pd_to_ks_clean
 from featuretools.variable_types import Boolean, Datetime, Numeric, Variable
 
-ks = import_or_none('databricks.koalas')
-
 
 def test_init_and_name(es):
     log = es['log']
@@ -75,9 +74,9 @@ def test_init_and_name(es):
     customers_features = [ft.Feature(v) for v in es["customers"].variables]
     trans_primitives = get_transform_primitives().values()
     # If Dask EntitySet use only Dask compatible primitives
-    if isinstance(es['log'].df, dd.DataFrame):
+    if es.dataframe_type == Library.DASK.value:
         trans_primitives = [prim for prim in trans_primitives if Library.DASK in prim.compatibility]
-    if ks and isinstance(es['log'].df, ks.DataFrame):
+    if es.dataframe_type == Library.KOALAS.value:
         trans_primitives = [prim for prim in trans_primitives if Library.KOALAS in prim.compatibility]
     for transform_prim in trans_primitives:
         # skip automated testing if a few special cases
@@ -139,7 +138,7 @@ def test_make_trans_feat(es):
 
 
 @pytest.fixture
-def simple_es():
+def pd_simple_es():
     df = pd.DataFrame({
         'id': range(4),
         'value': pd.Categorical(['a', 'c', 'b', 'd']),
@@ -157,15 +156,57 @@ def simple_es():
     return es
 
 
+@pytest.fixture
+def dd_simple_es(pd_simple_es):
+    entities = {}
+    for entity in pd_simple_es.entities:
+        entities[entity.id] = (dd.from_pandas(entity.df.reset_index(drop=True), npartitions=4),
+                               entity.index,
+                               None,
+                               entity.variable_types)
+
+    relationships = [(rel.parent_entity.id,
+                      rel.parent_variable.name,
+                      rel.child_entity.id,
+                      rel.child_variable.name) for rel in pd_simple_es.relationships]
+
+    return ft.EntitySet(id=pd_simple_es.id, entities=entities, relationships=relationships)
+
+
+@pytest.fixture
+def ks_simple_es(pd_simple_es):
+    ks = pytest.importorskip('databricks.koalas', reason="Koalas not installed, skipping")
+    entities = {}
+    for entity in pd_simple_es.entities:
+        cleaned_df = pd_to_ks_clean(entity.df).reset_index(drop=True)
+        entities[entity.id] = (ks.from_pandas(cleaned_df),
+                               entity.index,
+                               None,
+                               entity.variable_types)
+
+    relationships = [(rel.parent_entity.id,
+                      rel.parent_variable.name,
+                      rel.child_entity.id,
+                      rel.child_variable.name) for rel in pd_simple_es.relationships]
+
+    return ft.EntitySet(id=pd_simple_es.id, entities=entities, relationships=relationships)
+
+
+@pytest.fixture(params=['pd_simple_es', 'dd_simple_es', 'ks_simple_es'])
+def simple_es(request):
+    return request.getfixturevalue(request.param)
+
+
 def test_equal_categorical(simple_es):
     f1 = ft.Feature([simple_es['values']['value'], simple_es['values']['value2']],
                     primitive=Equal)
 
     df = ft.calculate_feature_matrix(entityset=simple_es, features=[f1])
-
-    assert set(simple_es['values'].df['value'].cat.categories) != \
-        set(simple_es['values'].df['value2'].cat.categories)
-    assert df['value = value2'].to_list() == [True, False, False, True]
+    if simple_es.dataframe_type != Library.KOALAS.value:
+        # Koalas does not support categorical dtype
+        assert set(simple_es['values'].df['value'].cat.categories) != \
+            set(simple_es['values'].df['value2'].cat.categories)
+    assert to_pandas(df, index='id', sort_index=True)['value = value2'].to_list() == [True, False, False, True]
 
 
 def test_equal_different_dtypes(simple_es):
@@ -177,8 +218,8 @@ def test_equal_different_dtypes(simple_es):
     # verify that equals works for different dtypes regardless of order
     df = ft.calculate_feature_matrix(entityset=simple_es, features=[f1, f2])
 
-    assert df['object = datetime'].to_list() == [False, False, False, False]
-    assert df['datetime = object'].to_list() == [False, False, False, False]
+    assert to_pandas(df, index='id', sort_index=True)['object = datetime'].to_list() == [False, False, False, False]
+    assert to_pandas(df, index='id', sort_index=True)['datetime = object'].to_list() == [False, False, False, False]
 
 
 def test_not_equal_categorical(simple_es):
@@ -187,9 +228,11 @@ def test_not_equal_categorical(simple_es):
 
     df = ft.calculate_feature_matrix(entityset=simple_es, features=[f1])
 
-    assert set(simple_es['values'].df['value'].cat.categories) != \
-        set(simple_es['values'].df['value2'].cat.categories)
-    assert df['value != value2'].to_list() == [False, True, True, False]
+    if simple_es.dataframe_type != Library.KOALAS.value:
+        # Koalas does not support categorical dtype
+        assert set(simple_es['values'].df['value'].cat.categories) != \
+            set(simple_es['values'].df['value2'].cat.categories)
+    assert to_pandas(df, index='id', sort_index=True)['value != value2'].to_list() == [False, True, True, False]
 
 
 def test_not_equal_different_dtypes(simple_es):
@@ -201,8 +244,8 @@ def test_not_equal_different_dtypes(simple_es):
     # verify that equals works for different dtypes regardless of order
     df = ft.calculate_feature_matrix(entityset=simple_es, features=[f1, f2])
 
-    assert df['object != datetime'].to_list() == [True, True, True, True]
-    assert df['datetime != object'].to_list() == [True, True, True, True]
+    assert to_pandas(df, index='id', sort_index=True)['object != datetime'].to_list() == [True, True, True, True]
+    assert to_pandas(df, index='id', sort_index=True)['datetime != object'].to_list() == [True, True, True, True]
 
 
 def test_diff(pd_es):
@@ -347,7 +390,7 @@ def test_compare_of_agg(es):
 
 
 def test_compare_all_nans(es):
-    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+    if es.dataframe_type != Library.PANDAS.value:
         nan_feat = ft.Feature(es['log']['value'], parent_entity=es['sessions'], primitive=ft.primitives.Min)
         compare = nan_feat == 0.0
     else:
@@ -405,7 +448,7 @@ def test_arithmetic_of_identity(es):
                (MultiplyNumeric, [0, 10, 40, 90]),
                (DivideNumeric, [np.nan, 2.5, 2.5, 2.5])]
     # SubtractNumeric not supported for Koalas EntitySets
-    if ks and any(isinstance(e.df, ks.DataFrame) for e in es.entities):
+    if es.dataframe_type == Library.KOALAS.value:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -435,7 +478,7 @@ def test_arithmetic_of_direct(es):
                (SubtractNumeric, [28, 29, 28.5, 28.5]),
                (MultiplyNumeric, [165, 132, 148.5, 148.5]),
                (DivideNumeric, [6.6, 8.25, 22. / 3, 22. / 3])]
-    if ks and any(isinstance(e.df, ks.DataFrame) for e in es.entities):
+    if es.dataframe_type == Library.KOALAS.value:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -505,7 +548,7 @@ def test_boolean_multiply(boolean_mult_es):
 
 # TODO: rework test to be Dask and Koalas compatible
 def test_arithmetic_of_transform(es):
-    if not all(isinstance(e.df, pd.DataFrame) for e in es.entities):
+    if es.dataframe_type != Library.PANDAS.value:
         pytest.xfail("Test uses Diff which is not supported in Dask or Koalas")
     diff1 = ft.Feature([es['log']['value']], primitive=Diff)
     diff2 = ft.Feature([es['log']['value_2']], primitive=Diff)
@@ -548,7 +591,7 @@ def test_arithmetic_of_agg(es):
                (MultiplyNumeric, [9, 0]),
                (DivideNumeric, [1, 0])]
     # Skip SubtractNumeric for Koalas as it's unsupported
-    if ks and any(isinstance(e.df, ks.DataFrame) for e in es.entities):
+    if es.dataframe_type == Library.KOALAS.value:
         to_test = to_test[:1] + to_test[2:]
 
     features = []
@@ -1115,7 +1158,7 @@ def test_override_multi_feature_names(pd_es):
 
 
 def test_time_since_primitive_matches_all_datetime_types(es):
-    if ks and any(isinstance(e.df, ks.DataFrame) for e in es.entities):
+    if es.dataframe_type == Library.KOALAS.value:
         pytest.xfail('TimeSince transform primitive is incompatible with Koalas')
     fm, fl = ft.dfs(
         target_entity="customers",
